#[non_exhaustive]#[repr(u16)]pub enum IssueCode {
Show 326 variants
AbstractClassUsedAsAttribute = 0,
AbstractInstantiation = 1,
AlwaysMatchingSwitchCase = 2,
AmbiguousClassLikeConstantAccess = 3,
AmbiguousInstantiationTarget = 4,
AmbiguousObjectMethodAccess = 5,
AmbiguousObjectPropertyAccess = 6,
ArrayAppendInReadContext = 7,
ArrayAppendOverflow = 8,
ArrayToStringConversion = 9,
AssignmentToConstant = 10,
AssignmentToThis = 11,
AttributeNotRepeatable = 12,
AvoidCatchingError = 13,
BackedPropertyReferenceHook = 14,
CatchTypeNotThrowable = 15,
ClassMustBeFinal = 16,
ClassNotMarkedAsAttribute = 17,
CloneInsideLoop = 18,
ConditionIsTooComplex = 19,
ConflictingReferenceConstraint = 20,
ConflictingTemplateEqualityBounds = 21,
DeprecatedClass = 22,
DeprecatedClosure = 23,
DeprecatedConstant = 24,
DeprecatedFeature = 25,
DeprecatedFunction = 26,
DeprecatedMethod = 27,
DeprecatedTrait = 28,
DirectTraitConstantAccess = 29,
DocblockParameterNarrowing = 30,
DocblockTypeMismatch = 31,
DuplicateArrayKey = 32,
DuplicateCaughtType = 33,
DuplicateClosureUseVariable = 34,
DuplicateDefinition = 35,
DuplicateEnumCaseValue = 36,
DuplicateNamedArgument = 37,
DuplicateSwitchCase = 38,
DynamicStaticMethodCall = 39,
EmptyMatchExpression = 40,
EnumInstantiation = 41,
EnumIteration = 42,
ExcessTemplateParameter = 43,
ExperimentalUsage = 44,
ExpressionIsTooComplex = 45,
ExtendFinalClass = 46,
FalsableReturnStatement = 47,
FalseArgument = 48,
FalseArrayAccess = 49,
FalseIterator = 50,
FalseOperand = 51,
GenericObjectIteration = 52,
HiddenGeneratorReturn = 53,
ImplicitResourceToStringCast = 54,
ImplicitToStringCast = 55,
ImpossibleArrayAccess = 56,
ImpossibleArrayAssignment = 57,
ImpossibleAssignment = 58,
ImpossibleCondition = 59,
ImpossibleKeyCheck = 60,
ImpossibleNonnullEntryCheck = 61,
ImpossibleNullTypeComparison = 62,
ImpossibleTypeComparison = 63,
ImpreciseType = 64,
ImpureConstruct = 65,
ImpureStaticVariable = 66,
IncompatibleConstantAccess = 67,
IncompatibleConstantOverride = 68,
IncompatibleConstantType = 69,
IncompatibleConstantVisibility = 70,
IncompatibleParameterCount = 71,
IncompatibleParameterName = 72,
IncompatibleParameterType = 73,
IncompatiblePropertyAccess = 74,
IncompatiblePropertyDefault = 75,
IncompatiblePropertyHookParameterType = 76,
IncompatiblePropertyHookSignature = 77,
IncompatiblePropertyOverride = 78,
IncompatiblePropertyReadonly = 79,
IncompatiblePropertyStatic = 80,
IncompatiblePropertyType = 81,
IncompatiblePropertyVisibility = 82,
IncompatibleReadonlyModifier = 83,
IncompatibleReturnType = 84,
IncompatibleStaticModifier = 85,
IncompatibleTemplateLowerBound = 86,
IncompatibleVisibility = 87,
InconsistentTemplate = 88,
IncorrectClassLikeCasing = 89,
IncorrectFunctionCasing = 90,
InterfaceInstantiation = 91,
InvalidArgument = 92,
InvalidArrayAccess = 93,
InvalidArrayAccessAssignmentValue = 94,
InvalidArrayElement = 95,
InvalidArrayElementKey = 96,
InvalidArrayIndex = 97,
InvalidAssignment = 98,
InvalidAttributeTarget = 99,
InvalidBreak = 100,
InvalidCallable = 101,
InvalidCatchType = 102,
InvalidCatchTypeNotClassOrInterface = 103,
InvalidClassConstantOnString = 104,
InvalidClassStringExpression = 105,
InvalidClone = 106,
InvalidConstantSelector = 107,
InvalidConstantValue = 108,
InvalidContinue = 109,
InvalidDestructuringSource = 110,
InvalidDocblock = 111,
InvalidEnumCaseValue = 112,
InvalidExtend = 113,
InvalidForeachKey = 114,
InvalidForeachValue = 115,
InvalidGeneratorReturnType = 116,
InvalidGlobal = 117,
InvalidImplement = 118,
InvalidIssetExpression = 119,
InvalidIterator = 120,
InvalidMemberSelector = 121,
InvalidMethodAccess = 122,
InvalidNamedArgument = 123,
InvalidOperand = 124,
InvalidOverrideAttribute = 125,
InvalidParameterDefaultValue = 126,
InvalidParentType = 127,
InvalidPassByReference = 128,
InvalidPropertyAccess = 129,
InvalidPropertyAssignmentValue = 130,
InvalidPropertyDefaultValue = 131,
InvalidPropertyRead = 132,
InvalidPropertyWrite = 133,
InvalidReturnStatement = 134,
InvalidScopeKeywordContext = 135,
InvalidStaticMethodAccess = 136,
InvalidStaticMethodCall = 137,
InvalidStaticPropertyAccess = 138,
InvalidTemplateParameter = 139,
InvalidThrow = 140,
InvalidTraitAliasModifier = 141,
InvalidTraitUse = 142,
InvalidTypeCast = 143,
InvalidUnset = 144,
InvalidYieldKeyType = 145,
InvalidYieldValueType = 146,
LessSpecificArgument = 147,
LessSpecificNestedArgumentType = 148,
LessSpecificNestedReturnStatement = 149,
LessSpecificReturnStatement = 150,
ListDestructureNegativeKey = 151,
ListDestructureStringKey = 152,
ListUsedInReadContext = 153,
MatchArmAlwaysTrue = 154,
MatchDefaultArmAlwaysExecuted = 155,
MatchExpressionOnlyDefaultArm = 156,
MatchNotExhaustive = 157,
MatchSubjectTypeIsNever = 158,
MethodAccessOnNull = 159,
MismatchedArrayIndex = 160,
MissingApiOrInternal = 161,
MissingConstantType = 162,
MissingConstructor = 163,
MissingMagicMethod = 164,
MissingOverrideAttribute = 165,
MissingParameterType = 166,
MissingPropertyType = 167,
MissingRequiredInterface = 168,
MissingRequiredParent = 169,
MissingReturnStatement = 170,
MissingReturnType = 171,
MissingTemplateParameter = 172,
MixedArgument = 173,
MixedArrayAccess = 174,
MixedArrayAssignment = 175,
MixedArrayIndex = 176,
MixedAssignment = 177,
MixedClone = 178,
MixedDestructuringShape = 179,
MixedMethodAccess = 180,
MixedOperand = 181,
MixedPropertyAccess = 182,
MixedPropertyTypeCoercion = 183,
MixedReturnStatement = 184,
NameAlreadyInUse = 185,
NamedArgumentAfterPositional = 186,
NamedArgumentNotAllowed = 187,
NamedArgumentOverridesPositional = 188,
NeverMatchingSwitchCase = 189,
NeverReturn = 190,
NoValidCatchTypeFound = 191,
NoValue = 192,
NonClassUsedAsAttribute = 193,
NonDocumentedConstant = 194,
NonDocumentedMethod = 195,
NonDocumentedProperty = 196,
NonExistentAttributeClass = 197,
NonExistentCatchType = 198,
NonExistentClass = 199,
NonExistentClassConstant = 200,
NonExistentClassLike = 201,
NonExistentConstant = 202,
NonExistentFunction = 203,
NonExistentMethod = 204,
NonExistentProperty = 205,
NonExistentUseImport = 206,
NonIterableObjectIteration = 207,
NonStaticAbstractImplementation = 208,
NullArgument = 209,
NullArrayAccess = 210,
NullArrayIndex = 211,
NullDestructuringSource = 212,
NullIterator = 213,
NullOperand = 214,
NullPropertyAccess = 215,
NullableReturnStatement = 216,
OverlyWideReturnType = 217,
OverrideFinalConstant = 218,
OverrideFinalMethod = 219,
OverrideFinalProperty = 220,
OverrideFinalPropertyHook = 221,
ParadoxicalCondition = 222,
ParentOutsideClassScope = 223,
PossibleMethodAccessOnNull = 224,
PossiblyArrayAppendOverflow = 225,
PossiblyFalseArgument = 226,
PossiblyFalseArrayAccess = 227,
PossiblyFalseIterator = 228,
PossiblyFalseOperand = 229,
PossiblyInvalidArgument = 230,
PossiblyInvalidArrayAccess = 231,
PossiblyInvalidClone = 232,
PossiblyInvalidIterator = 233,
PossiblyInvalidOperand = 234,
PossiblyInvalidPropertyWrite = 235,
PossiblyNonExistentMethod = 236,
PossiblyNonExistentProperty = 237,
PossiblyNullArgument = 238,
PossiblyNullArrayAccess = 239,
PossiblyNullArrayIndex = 240,
PossiblyNullDestructuringSource = 241,
PossiblyNullIterator = 242,
PossiblyNullOperand = 243,
PossiblyNullPropertyAccess = 244,
PossiblyStaticAccessOnInterface = 245,
PossiblyUndefinedArrayIndex = 246,
PossiblyUndefinedIntArrayIndex = 247,
PossiblyUndefinedStringArrayIndex = 248,
PossiblyUndefinedVariable = 249,
PropertyTypeCoercion = 250,
PsalmTrace = 251,
RedundantCast = 252,
RedundantComparison = 253,
RedundantCondition = 254,
RedundantDocblockType = 255,
RedundantIssetCheck = 256,
RedundantKeyCheck = 257,
RedundantLogicalOperation = 258,
RedundantNonnullEntryCheck = 259,
RedundantNonnullTypeComparison = 260,
RedundantNullCoalesce = 261,
RedundantNullsafeOperator = 262,
RedundantTypeComparison = 263,
ReferenceConstraintViolation = 264,
ReferenceReusedFromConfusingScope = 265,
ReferenceToUndefinedVariable = 266,
SelfOutsideClassScope = 267,
SideEffectsInCondition = 268,
SkipInKeyedDestructuring = 269,
SpreadInDestructuring = 270,
StaticAccessOnInterface = 271,
StaticOutsideClassScope = 272,
StringConstantSelector = 273,
StringMemberSelector = 274,
TemplateConstraintViolation = 275,
TooFewArguments = 276,
TooManyArguments = 277,
TraitConstantOverride = 278,
TraitInstantiation = 279,
TypeConfirmation = 280,
TypeInspection = 281,
UnavailableClassConstant = 282,
UnavailableClassLike = 283,
UnavailableConstant = 284,
UnavailableEnumCase = 285,
UnavailableFunction = 286,
UnavailableMethod = 287,
UnavailableProperty = 288,
UndefinedIntArrayIndex = 289,
UndefinedStringArrayIndex = 290,
UndefinedVariable = 291,
UndefinedVariableInClosureUse = 292,
UnevaluatedCode = 293,
UnhandledThrownType = 294,
UnimplementedAbstractMethod = 295,
UnimplementedAbstractPropertyHook = 296,
UninitializedProperty = 297,
UnknownClassInstantiation = 298,
UnknownConstantSelectorType = 299,
UnknownIteratorType = 300,
UnknownMatchSubjectType = 301,
UnknownMemberSelectorType = 302,
UnknownYieldFromIteratorType = 303,
UnreachableElseClause = 304,
UnreachableMatchArm = 305,
UnreachableMatchDefaultArm = 306,
UnreachableSwitchCase = 307,
UnreachableSwitchDefault = 308,
UnresolvableClassConstant = 309,
UnsafeInstantiation = 310,
UnusedFunctionCall = 311,
UnusedMethod = 312,
UnusedMethodCall = 313,
UnusedParameter = 314,
UnusedProperty = 315,
UnusedStatement = 316,
UnusedTemplateParameter = 317,
UselessControlFlow = 318,
WhereConstraintViolation = 319,
WriteOnlyProperty = 320,
YieldFromInvalidKeyType = 321,
YieldFromInvalidSendType = 322,
YieldFromInvalidValueType = 323,
YieldFromNonIterable = 324,
YieldOutsideFunction = 325,
}Expand description
An issue code representing a specific type of analysis issue.
Each issue code corresponds to a unique identifier for a particular kind of issue that the analyzer can detect during code analysis.
This enum is non-exhaustive; new issue codes may be added in future versions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AbstractClassUsedAsAttribute = 0
AbstractInstantiation = 1
AlwaysMatchingSwitchCase = 2
AmbiguousClassLikeConstantAccess = 3
AmbiguousInstantiationTarget = 4
AmbiguousObjectMethodAccess = 5
AmbiguousObjectPropertyAccess = 6
ArrayAppendInReadContext = 7
ArrayAppendOverflow = 8
ArrayToStringConversion = 9
AssignmentToConstant = 10
AssignmentToThis = 11
AttributeNotRepeatable = 12
AvoidCatchingError = 13
BackedPropertyReferenceHook = 14
CatchTypeNotThrowable = 15
ClassMustBeFinal = 16
ClassNotMarkedAsAttribute = 17
CloneInsideLoop = 18
ConditionIsTooComplex = 19
ConflictingReferenceConstraint = 20
ConflictingTemplateEqualityBounds = 21
DeprecatedClass = 22
DeprecatedClosure = 23
DeprecatedConstant = 24
DeprecatedFeature = 25
DeprecatedFunction = 26
DeprecatedMethod = 27
DeprecatedTrait = 28
DirectTraitConstantAccess = 29
DocblockParameterNarrowing = 30
DocblockTypeMismatch = 31
DuplicateArrayKey = 32
DuplicateCaughtType = 33
DuplicateClosureUseVariable = 34
DuplicateDefinition = 35
DuplicateEnumCaseValue = 36
DuplicateNamedArgument = 37
DuplicateSwitchCase = 38
DynamicStaticMethodCall = 39
EmptyMatchExpression = 40
EnumInstantiation = 41
EnumIteration = 42
ExcessTemplateParameter = 43
ExperimentalUsage = 44
ExpressionIsTooComplex = 45
ExtendFinalClass = 46
FalsableReturnStatement = 47
FalseArgument = 48
FalseArrayAccess = 49
FalseIterator = 50
FalseOperand = 51
GenericObjectIteration = 52
HiddenGeneratorReturn = 53
ImplicitResourceToStringCast = 54
ImplicitToStringCast = 55
ImpossibleArrayAccess = 56
ImpossibleArrayAssignment = 57
ImpossibleAssignment = 58
ImpossibleCondition = 59
ImpossibleKeyCheck = 60
ImpossibleNonnullEntryCheck = 61
ImpossibleNullTypeComparison = 62
ImpossibleTypeComparison = 63
ImpreciseType = 64
ImpureConstruct = 65
ImpureStaticVariable = 66
IncompatibleConstantAccess = 67
IncompatibleConstantOverride = 68
IncompatibleConstantType = 69
IncompatibleConstantVisibility = 70
IncompatibleParameterCount = 71
IncompatibleParameterName = 72
IncompatibleParameterType = 73
IncompatiblePropertyAccess = 74
IncompatiblePropertyDefault = 75
IncompatiblePropertyHookParameterType = 76
IncompatiblePropertyHookSignature = 77
IncompatiblePropertyOverride = 78
IncompatiblePropertyReadonly = 79
IncompatiblePropertyStatic = 80
IncompatiblePropertyType = 81
IncompatiblePropertyVisibility = 82
IncompatibleReadonlyModifier = 83
IncompatibleReturnType = 84
IncompatibleStaticModifier = 85
IncompatibleTemplateLowerBound = 86
IncompatibleVisibility = 87
InconsistentTemplate = 88
IncorrectClassLikeCasing = 89
IncorrectFunctionCasing = 90
InterfaceInstantiation = 91
InvalidArgument = 92
InvalidArrayAccess = 93
InvalidArrayAccessAssignmentValue = 94
InvalidArrayElement = 95
InvalidArrayElementKey = 96
InvalidArrayIndex = 97
InvalidAssignment = 98
InvalidAttributeTarget = 99
InvalidBreak = 100
InvalidCallable = 101
InvalidCatchType = 102
InvalidCatchTypeNotClassOrInterface = 103
InvalidClassConstantOnString = 104
InvalidClassStringExpression = 105
InvalidClone = 106
InvalidConstantSelector = 107
InvalidConstantValue = 108
InvalidContinue = 109
InvalidDestructuringSource = 110
InvalidDocblock = 111
InvalidEnumCaseValue = 112
InvalidExtend = 113
InvalidForeachKey = 114
InvalidForeachValue = 115
InvalidGeneratorReturnType = 116
InvalidGlobal = 117
InvalidImplement = 118
InvalidIssetExpression = 119
InvalidIterator = 120
InvalidMemberSelector = 121
InvalidMethodAccess = 122
InvalidNamedArgument = 123
InvalidOperand = 124
InvalidOverrideAttribute = 125
InvalidParameterDefaultValue = 126
InvalidParentType = 127
InvalidPassByReference = 128
InvalidPropertyAccess = 129
InvalidPropertyAssignmentValue = 130
InvalidPropertyDefaultValue = 131
InvalidPropertyRead = 132
InvalidPropertyWrite = 133
InvalidReturnStatement = 134
InvalidScopeKeywordContext = 135
InvalidStaticMethodAccess = 136
InvalidStaticMethodCall = 137
InvalidStaticPropertyAccess = 138
InvalidTemplateParameter = 139
InvalidThrow = 140
InvalidTraitAliasModifier = 141
InvalidTraitUse = 142
InvalidTypeCast = 143
InvalidUnset = 144
InvalidYieldKeyType = 145
InvalidYieldValueType = 146
LessSpecificArgument = 147
LessSpecificNestedArgumentType = 148
LessSpecificNestedReturnStatement = 149
LessSpecificReturnStatement = 150
ListDestructureNegativeKey = 151
ListDestructureStringKey = 152
ListUsedInReadContext = 153
MatchArmAlwaysTrue = 154
MatchDefaultArmAlwaysExecuted = 155
MatchExpressionOnlyDefaultArm = 156
MatchNotExhaustive = 157
MatchSubjectTypeIsNever = 158
MethodAccessOnNull = 159
MismatchedArrayIndex = 160
MissingApiOrInternal = 161
MissingConstantType = 162
MissingConstructor = 163
MissingMagicMethod = 164
MissingOverrideAttribute = 165
MissingParameterType = 166
MissingPropertyType = 167
MissingRequiredInterface = 168
MissingRequiredParent = 169
MissingReturnStatement = 170
MissingReturnType = 171
MissingTemplateParameter = 172
MixedArgument = 173
MixedArrayAccess = 174
MixedArrayAssignment = 175
MixedArrayIndex = 176
MixedAssignment = 177
MixedClone = 178
MixedDestructuringShape = 179
MixedMethodAccess = 180
MixedOperand = 181
MixedPropertyAccess = 182
MixedPropertyTypeCoercion = 183
MixedReturnStatement = 184
NameAlreadyInUse = 185
NamedArgumentAfterPositional = 186
NamedArgumentNotAllowed = 187
NamedArgumentOverridesPositional = 188
NeverMatchingSwitchCase = 189
NeverReturn = 190
NoValidCatchTypeFound = 191
NoValue = 192
NonClassUsedAsAttribute = 193
NonDocumentedConstant = 194
NonDocumentedMethod = 195
NonDocumentedProperty = 196
NonExistentAttributeClass = 197
NonExistentCatchType = 198
NonExistentClass = 199
NonExistentClassConstant = 200
NonExistentClassLike = 201
NonExistentConstant = 202
NonExistentFunction = 203
NonExistentMethod = 204
NonExistentProperty = 205
NonExistentUseImport = 206
NonIterableObjectIteration = 207
NonStaticAbstractImplementation = 208
NullArgument = 209
NullArrayAccess = 210
NullArrayIndex = 211
NullDestructuringSource = 212
NullIterator = 213
NullOperand = 214
NullPropertyAccess = 215
NullableReturnStatement = 216
OverlyWideReturnType = 217
OverrideFinalConstant = 218
OverrideFinalMethod = 219
OverrideFinalProperty = 220
OverrideFinalPropertyHook = 221
ParadoxicalCondition = 222
ParentOutsideClassScope = 223
PossibleMethodAccessOnNull = 224
PossiblyArrayAppendOverflow = 225
PossiblyFalseArgument = 226
PossiblyFalseArrayAccess = 227
PossiblyFalseIterator = 228
PossiblyFalseOperand = 229
PossiblyInvalidArgument = 230
PossiblyInvalidArrayAccess = 231
PossiblyInvalidClone = 232
PossiblyInvalidIterator = 233
PossiblyInvalidOperand = 234
PossiblyInvalidPropertyWrite = 235
PossiblyNonExistentMethod = 236
PossiblyNonExistentProperty = 237
PossiblyNullArgument = 238
PossiblyNullArrayAccess = 239
PossiblyNullArrayIndex = 240
PossiblyNullDestructuringSource = 241
PossiblyNullIterator = 242
PossiblyNullOperand = 243
PossiblyNullPropertyAccess = 244
PossiblyStaticAccessOnInterface = 245
PossiblyUndefinedArrayIndex = 246
PossiblyUndefinedIntArrayIndex = 247
PossiblyUndefinedStringArrayIndex = 248
PossiblyUndefinedVariable = 249
PropertyTypeCoercion = 250
PsalmTrace = 251
RedundantCast = 252
RedundantComparison = 253
RedundantCondition = 254
RedundantDocblockType = 255
RedundantIssetCheck = 256
RedundantKeyCheck = 257
RedundantLogicalOperation = 258
RedundantNonnullEntryCheck = 259
RedundantNonnullTypeComparison = 260
RedundantNullCoalesce = 261
RedundantNullsafeOperator = 262
RedundantTypeComparison = 263
ReferenceConstraintViolation = 264
ReferenceReusedFromConfusingScope = 265
ReferenceToUndefinedVariable = 266
SelfOutsideClassScope = 267
SideEffectsInCondition = 268
SkipInKeyedDestructuring = 269
SpreadInDestructuring = 270
StaticAccessOnInterface = 271
StaticOutsideClassScope = 272
StringConstantSelector = 273
StringMemberSelector = 274
TemplateConstraintViolation = 275
TooFewArguments = 276
TooManyArguments = 277
TraitConstantOverride = 278
TraitInstantiation = 279
TypeConfirmation = 280
TypeInspection = 281
UndefinedIntArrayIndex = 289
UndefinedStringArrayIndex = 290
UndefinedVariable = 291
UndefinedVariableInClosureUse = 292
UnevaluatedCode = 293
UnhandledThrownType = 294
UnimplementedAbstractMethod = 295
UnimplementedAbstractPropertyHook = 296
UninitializedProperty = 297
UnknownClassInstantiation = 298
UnknownConstantSelectorType = 299
UnknownIteratorType = 300
UnknownMatchSubjectType = 301
UnknownMemberSelectorType = 302
UnknownYieldFromIteratorType = 303
UnreachableElseClause = 304
UnreachableMatchArm = 305
UnreachableMatchDefaultArm = 306
UnreachableSwitchCase = 307
UnreachableSwitchDefault = 308
UnresolvableClassConstant = 309
UnsafeInstantiation = 310
UnusedFunctionCall = 311
UnusedMethod = 312
UnusedMethodCall = 313
UnusedParameter = 314
UnusedProperty = 315
UnusedStatement = 316
UnusedTemplateParameter = 317
UselessControlFlow = 318
WhereConstraintViolation = 319
WriteOnlyProperty = 320
YieldFromInvalidKeyType = 321
YieldFromInvalidSendType = 322
YieldFromInvalidValueType = 323
YieldFromNonIterable = 324
YieldOutsideFunction = 325
Implementations