pub struct ExternalAnalyzer<T = WorkerPool> { /* private fields */ }Implementations
Sourceimpl ExternalAnalyzer<WorkerPool>
impl ExternalAnalyzer<WorkerPool>
Sourcepub fn initialize(
pools: impl IntoIterator<Item = Arc<WorkerPool>>,
php_version: PHPVersion,
enabled_plugins: &[String],
disable_defaults: bool,
) -> Result<Self, ExternalAnalyzerError>
pub fn initialize( pools: impl IntoIterator<Item = Arc<WorkerPool>>, php_version: PHPVersion, enabled_plugins: &[String], disable_defaults: bool, ) -> Result<Self, ExternalAnalyzerError>
Discovers and validates the analyzer plugins exposed by worker pools.
Errors
Returns an error when a worker fails, sends malformed metadata, disagrees with another process in its pool, or advertises duplicate identifiers.
Sourceimpl<T> ExternalAnalyzer<T>
impl<T> ExternalAnalyzer<T>
pub fn extensions(&self) -> &[ExternalExtension]
pub fn initialization_files(&self) -> Vec<File>