pub struct SelectKeysProvider;Expand description
Provider for the Psl\Dict\select_keys() function.
Narrows the return type based on the literal keys in the $keys argument:
- If the input is a keyed array with known items AND keys are literals, returns only the matching known items.
- If the input is a generic iterable/array and keys are literals, returns a shaped array with optional entries for each key.
- Falls back to
None(generic return type) otherwise.