resolve_sprintf

Function resolve_sprintf 

pub fn resolve_sprintf(
    context: &ProviderContext<'_, '_, '_>,
    invocation: &InvocationInfo<'_, '_, '_>,
) -> Option<TUnion>
Resolve the return type of a sprintf-like call.

Expects the first argument to be the format string and subsequent arguments to be the format values (standard sprintf / Psl\Str\format signature).