#[non_exhaustive]#[repr(u16)]pub enum IssueCode {
Show 322 variants
AbstractClassUsedAsAttribute = 0,
AbstractInstantiation = 1,
AlwaysMatchingSwitchCase = 2,
AmbiguousClassLikeConstantAccess = 3,
AmbiguousInstantiationTarget = 4,
AmbiguousObjectMethodAccess = 5,
AmbiguousObjectPropertyAccess = 6,
ArrayAppendInReadContext = 7,
ArrayAppendOverflow = 8,
ArrayToStringConversion = 9,
AssignmentToConstant = 10,
AssignmentToThis = 11,
AttributeNotRepeatable = 12,
AvoidCatchingError = 13,
BackedPropertyReferenceHook = 14,
CatchTypeNotThrowable = 15,
ClassMustBeFinal = 16,
ClassNotMarkedAsAttribute = 17,
CloneInsideLoop = 18,
ConditionIsTooComplex = 19,
ConflictingReferenceConstraint = 20,
ConflictingTemplateEqualityBounds = 21,
DeprecatedClass = 22,
DeprecatedClosure = 23,
DeprecatedConstant = 24,
DeprecatedFeature = 25,
DeprecatedFunction = 26,
DeprecatedMethod = 27,
DeprecatedTrait = 28,
DirectTraitConstantAccess = 29,
DocblockParameterNarrowing = 30,
DocblockTypeMismatch = 31,
DuplicateArrayKey = 32,
DuplicateCaughtType = 33,
DuplicateClosureUseVariable = 34,
DuplicateDefinition = 35,
DuplicateEnumCaseValue = 36,
DuplicateNamedArgument = 37,
DynamicStaticMethodCall = 38,
EmptyMatchExpression = 39,
EnumInstantiation = 40,
EnumIteration = 41,
ExcessTemplateParameter = 42,
ExperimentalUsage = 43,
ExpressionIsTooComplex = 44,
ExtendFinalClass = 45,
FalsableReturnStatement = 46,
FalseArgument = 47,
FalseArrayAccess = 48,
FalseIterator = 49,
FalseOperand = 50,
GenericObjectIteration = 51,
HiddenGeneratorReturn = 52,
ImplicitResourceToStringCast = 53,
ImplicitToStringCast = 54,
ImpossibleArrayAccess = 55,
ImpossibleArrayAssignment = 56,
ImpossibleAssignment = 57,
ImpossibleCondition = 58,
ImpossibleKeyCheck = 59,
ImpossibleNonnullEntryCheck = 60,
ImpossibleNullTypeComparison = 61,
ImpossibleTypeComparison = 62,
ImpreciseType = 63,
ImpureConstruct = 64,
ImpureStaticVariable = 65,
IncompatibleConstantAccess = 66,
IncompatibleConstantOverride = 67,
IncompatibleConstantType = 68,
IncompatibleConstantVisibility = 69,
IncompatibleParameterCount = 70,
IncompatibleParameterName = 71,
IncompatibleParameterType = 72,
IncompatiblePropertyAccess = 73,
IncompatiblePropertyDefault = 74,
IncompatiblePropertyHookParameterType = 75,
IncompatiblePropertyHookSignature = 76,
IncompatiblePropertyOverride = 77,
IncompatiblePropertyReadonly = 78,
IncompatiblePropertyStatic = 79,
IncompatiblePropertyType = 80,
IncompatiblePropertyVisibility = 81,
IncompatibleReadonlyModifier = 82,
IncompatibleReturnType = 83,
IncompatibleStaticModifier = 84,
IncompatibleTemplateLowerBound = 85,
IncompatibleVisibility = 86,
InconsistentTemplate = 87,
IncorrectClassLikeCasing = 88,
IncorrectFunctionCasing = 89,
InterfaceInstantiation = 90,
InvalidArgument = 91,
InvalidArrayAccess = 92,
InvalidArrayAccessAssignmentValue = 93,
InvalidArrayElement = 94,
InvalidArrayElementKey = 95,
InvalidArrayIndex = 96,
InvalidAssignment = 97,
InvalidAttributeTarget = 98,
InvalidBreak = 99,
InvalidCallable = 100,
InvalidCatchType = 101,
InvalidCatchTypeNotClassOrInterface = 102,
InvalidClassConstantOnString = 103,
InvalidClassStringExpression = 104,
InvalidClone = 105,
InvalidConstantSelector = 106,
InvalidConstantValue = 107,
InvalidContinue = 108,
InvalidDestructuringSource = 109,
InvalidDocblock = 110,
InvalidEnumCaseValue = 111,
InvalidExtend = 112,
InvalidForeachKey = 113,
InvalidForeachValue = 114,
InvalidGeneratorReturnType = 115,
InvalidGlobal = 116,
InvalidImplement = 117,
InvalidIssetExpression = 118,
InvalidIterator = 119,
InvalidMemberSelector = 120,
InvalidMethodAccess = 121,
InvalidNamedArgument = 122,
InvalidOperand = 123,
InvalidOverrideAttribute = 124,
InvalidParameterDefaultValue = 125,
InvalidParentType = 126,
InvalidPassByReference = 127,
InvalidPropertyAccess = 128,
InvalidPropertyAssignmentValue = 129,
InvalidPropertyDefaultValue = 130,
InvalidPropertyRead = 131,
InvalidPropertyWrite = 132,
InvalidReturnStatement = 133,
InvalidScopeKeywordContext = 134,
InvalidStaticMethodAccess = 135,
InvalidStaticMethodCall = 136,
InvalidStaticPropertyAccess = 137,
InvalidTemplateParameter = 138,
InvalidThrow = 139,
InvalidTraitAliasModifier = 140,
InvalidTraitUse = 141,
InvalidTypeCast = 142,
InvalidUnset = 143,
InvalidYieldKeyType = 144,
InvalidYieldValueType = 145,
LessSpecificArgument = 146,
LessSpecificNestedArgumentType = 147,
LessSpecificNestedReturnStatement = 148,
LessSpecificReturnStatement = 149,
ListDestructureNegativeKey = 150,
ListDestructureStringKey = 151,
ListUsedInReadContext = 152,
MatchArmAlwaysTrue = 153,
MatchDefaultArmAlwaysExecuted = 154,
MatchExpressionOnlyDefaultArm = 155,
MatchNotExhaustive = 156,
MatchSubjectTypeIsNever = 157,
MethodAccessOnNull = 158,
MismatchedArrayIndex = 159,
MissingApiOrInternal = 160,
MissingConstantType = 161,
MissingConstructor = 162,
MissingMagicMethod = 163,
MissingOverrideAttribute = 164,
MissingParameterType = 165,
MissingPropertyType = 166,
MissingRequiredInterface = 167,
MissingRequiredParent = 168,
MissingReturnStatement = 169,
MissingReturnType = 170,
MissingTemplateParameter = 171,
MixedArgument = 172,
MixedArrayAccess = 173,
MixedArrayAssignment = 174,
MixedArrayIndex = 175,
MixedAssignment = 176,
MixedClone = 177,
MixedDestructuringShape = 178,
MixedMethodAccess = 179,
MixedOperand = 180,
MixedPropertyAccess = 181,
MixedPropertyTypeCoercion = 182,
MixedReturnStatement = 183,
NameAlreadyInUse = 184,
NamedArgumentAfterPositional = 185,
NamedArgumentNotAllowed = 186,
NamedArgumentOverridesPositional = 187,
NeverMatchingSwitchCase = 188,
NeverReturn = 189,
NoValidCatchTypeFound = 190,
NoValue = 191,
NonClassUsedAsAttribute = 192,
NonDocumentedConstant = 193,
NonDocumentedMethod = 194,
NonDocumentedProperty = 195,
NonExistentAttributeClass = 196,
NonExistentCatchType = 197,
NonExistentClass = 198,
NonExistentClassConstant = 199,
NonExistentClassLike = 200,
NonExistentConstant = 201,
NonExistentFunction = 202,
NonExistentMethod = 203,
NonExistentProperty = 204,
NonExistentUseImport = 205,
NonIterableObjectIteration = 206,
NonStaticAbstractImplementation = 207,
NullArgument = 208,
NullArrayAccess = 209,
NullArrayIndex = 210,
NullIterator = 211,
NullOperand = 212,
NullPropertyAccess = 213,
NullableReturnStatement = 214,
OverlyWideReturnType = 215,
OverrideFinalConstant = 216,
OverrideFinalMethod = 217,
OverrideFinalProperty = 218,
OverrideFinalPropertyHook = 219,
ParadoxicalCondition = 220,
ParentOutsideClassScope = 221,
PossibleMethodAccessOnNull = 222,
PossiblyArrayAppendOverflow = 223,
PossiblyFalseArgument = 224,
PossiblyFalseArrayAccess = 225,
PossiblyFalseIterator = 226,
PossiblyFalseOperand = 227,
PossiblyInvalidArgument = 228,
PossiblyInvalidArrayAccess = 229,
PossiblyInvalidClone = 230,
PossiblyInvalidIterator = 231,
PossiblyInvalidOperand = 232,
PossiblyNonExistentMethod = 233,
PossiblyNonExistentProperty = 234,
PossiblyNullArgument = 235,
PossiblyNullArrayAccess = 236,
PossiblyNullArrayIndex = 237,
PossiblyNullIterator = 238,
PossiblyNullOperand = 239,
PossiblyNullPropertyAccess = 240,
PossiblyStaticAccessOnInterface = 241,
PossiblyUndefinedArrayIndex = 242,
PossiblyUndefinedIntArrayIndex = 243,
PossiblyUndefinedStringArrayIndex = 244,
PossiblyUndefinedVariable = 245,
PropertyTypeCoercion = 246,
PsalmTrace = 247,
RedundantCast = 248,
RedundantComparison = 249,
RedundantCondition = 250,
RedundantDocblockType = 251,
RedundantIssetCheck = 252,
RedundantKeyCheck = 253,
RedundantLogicalOperation = 254,
RedundantNonnullEntryCheck = 255,
RedundantNonnullTypeComparison = 256,
RedundantNullCoalesce = 257,
RedundantNullsafeOperator = 258,
RedundantTypeComparison = 259,
ReferenceConstraintViolation = 260,
ReferenceReusedFromConfusingScope = 261,
ReferenceToUndefinedVariable = 262,
SelfOutsideClassScope = 263,
SideEffectsInCondition = 264,
SkipInKeyedDestructuring = 265,
SpreadInDestructuring = 266,
StaticAccessOnInterface = 267,
StaticOutsideClassScope = 268,
StringConstantSelector = 269,
StringMemberSelector = 270,
TemplateConstraintViolation = 271,
TooFewArguments = 272,
TooManyArguments = 273,
TraitConstantOverride = 274,
TraitInstantiation = 275,
TypeConfirmation = 276,
TypeInspection = 277,
UnavailableClassConstant = 278,
UnavailableClassLike = 279,
UnavailableConstant = 280,
UnavailableEnumCase = 281,
UnavailableFunction = 282,
UnavailableMethod = 283,
UnavailableProperty = 284,
UndefinedIntArrayIndex = 285,
UndefinedStringArrayIndex = 286,
UndefinedVariable = 287,
UndefinedVariableInClosureUse = 288,
UnevaluatedCode = 289,
UnhandledThrownType = 290,
UnimplementedAbstractMethod = 291,
UnimplementedAbstractPropertyHook = 292,
UninitializedProperty = 293,
UnknownClassInstantiation = 294,
UnknownConstantSelectorType = 295,
UnknownIteratorType = 296,
UnknownMatchSubjectType = 297,
UnknownMemberSelectorType = 298,
UnknownYieldFromIteratorType = 299,
UnreachableElseClause = 300,
UnreachableMatchArm = 301,
UnreachableMatchDefaultArm = 302,
UnreachableSwitchCase = 303,
UnreachableSwitchDefault = 304,
UnresolvableClassConstant = 305,
UnsafeInstantiation = 306,
UnusedFunctionCall = 307,
UnusedMethod = 308,
UnusedMethodCall = 309,
UnusedParameter = 310,
UnusedProperty = 311,
UnusedStatement = 312,
UnusedTemplateParameter = 313,
UselessControlFlow = 314,
WhereConstraintViolation = 315,
WriteOnlyProperty = 316,
YieldFromInvalidKeyType = 317,
YieldFromInvalidSendType = 318,
YieldFromInvalidValueType = 319,
YieldFromNonIterable = 320,
YieldOutsideFunction = 321,
}Expand description
An issue code representing a specific type of analysis issue.
Each issue code corresponds to a unique identifier for a particular kind of issue that the analyzer can detect during code analysis.
This enum is non-exhaustive; new issue codes may be added in future versions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AbstractClassUsedAsAttribute = 0
AbstractInstantiation = 1
AlwaysMatchingSwitchCase = 2
AmbiguousClassLikeConstantAccess = 3
AmbiguousInstantiationTarget = 4
AmbiguousObjectMethodAccess = 5
AmbiguousObjectPropertyAccess = 6
ArrayAppendInReadContext = 7
ArrayAppendOverflow = 8
ArrayToStringConversion = 9
AssignmentToConstant = 10
AssignmentToThis = 11
AttributeNotRepeatable = 12
AvoidCatchingError = 13
BackedPropertyReferenceHook = 14
CatchTypeNotThrowable = 15
ClassMustBeFinal = 16
ClassNotMarkedAsAttribute = 17
CloneInsideLoop = 18
ConditionIsTooComplex = 19
ConflictingReferenceConstraint = 20
ConflictingTemplateEqualityBounds = 21
DeprecatedClass = 22
DeprecatedClosure = 23
DeprecatedConstant = 24
DeprecatedFeature = 25
DeprecatedFunction = 26
DeprecatedMethod = 27
DeprecatedTrait = 28
DirectTraitConstantAccess = 29
DocblockParameterNarrowing = 30
DocblockTypeMismatch = 31
DuplicateArrayKey = 32
DuplicateCaughtType = 33
DuplicateClosureUseVariable = 34
DuplicateDefinition = 35
DuplicateEnumCaseValue = 36
DuplicateNamedArgument = 37
DynamicStaticMethodCall = 38
EmptyMatchExpression = 39
EnumInstantiation = 40
EnumIteration = 41
ExcessTemplateParameter = 42
ExperimentalUsage = 43
ExpressionIsTooComplex = 44
ExtendFinalClass = 45
FalsableReturnStatement = 46
FalseArgument = 47
FalseArrayAccess = 48
FalseIterator = 49
FalseOperand = 50
GenericObjectIteration = 51
HiddenGeneratorReturn = 52
ImplicitResourceToStringCast = 53
ImplicitToStringCast = 54
ImpossibleArrayAccess = 55
ImpossibleArrayAssignment = 56
ImpossibleAssignment = 57
ImpossibleCondition = 58
ImpossibleKeyCheck = 59
ImpossibleNonnullEntryCheck = 60
ImpossibleNullTypeComparison = 61
ImpossibleTypeComparison = 62
ImpreciseType = 63
ImpureConstruct = 64
ImpureStaticVariable = 65
IncompatibleConstantAccess = 66
IncompatibleConstantOverride = 67
IncompatibleConstantType = 68
IncompatibleConstantVisibility = 69
IncompatibleParameterCount = 70
IncompatibleParameterName = 71
IncompatibleParameterType = 72
IncompatiblePropertyAccess = 73
IncompatiblePropertyDefault = 74
IncompatiblePropertyHookParameterType = 75
IncompatiblePropertyHookSignature = 76
IncompatiblePropertyOverride = 77
IncompatiblePropertyReadonly = 78
IncompatiblePropertyStatic = 79
IncompatiblePropertyType = 80
IncompatiblePropertyVisibility = 81
IncompatibleReadonlyModifier = 82
IncompatibleReturnType = 83
IncompatibleStaticModifier = 84
IncompatibleTemplateLowerBound = 85
IncompatibleVisibility = 86
InconsistentTemplate = 87
IncorrectClassLikeCasing = 88
IncorrectFunctionCasing = 89
InterfaceInstantiation = 90
InvalidArgument = 91
InvalidArrayAccess = 92
InvalidArrayAccessAssignmentValue = 93
InvalidArrayElement = 94
InvalidArrayElementKey = 95
InvalidArrayIndex = 96
InvalidAssignment = 97
InvalidAttributeTarget = 98
InvalidBreak = 99
InvalidCallable = 100
InvalidCatchType = 101
InvalidCatchTypeNotClassOrInterface = 102
InvalidClassConstantOnString = 103
InvalidClassStringExpression = 104
InvalidClone = 105
InvalidConstantSelector = 106
InvalidConstantValue = 107
InvalidContinue = 108
InvalidDestructuringSource = 109
InvalidDocblock = 110
InvalidEnumCaseValue = 111
InvalidExtend = 112
InvalidForeachKey = 113
InvalidForeachValue = 114
InvalidGeneratorReturnType = 115
InvalidGlobal = 116
InvalidImplement = 117
InvalidIssetExpression = 118
InvalidIterator = 119
InvalidMemberSelector = 120
InvalidMethodAccess = 121
InvalidNamedArgument = 122
InvalidOperand = 123
InvalidOverrideAttribute = 124
InvalidParameterDefaultValue = 125
InvalidParentType = 126
InvalidPassByReference = 127
InvalidPropertyAccess = 128
InvalidPropertyAssignmentValue = 129
InvalidPropertyDefaultValue = 130
InvalidPropertyRead = 131
InvalidPropertyWrite = 132
InvalidReturnStatement = 133
InvalidScopeKeywordContext = 134
InvalidStaticMethodAccess = 135
InvalidStaticMethodCall = 136
InvalidStaticPropertyAccess = 137
InvalidTemplateParameter = 138
InvalidThrow = 139
InvalidTraitAliasModifier = 140
InvalidTraitUse = 141
InvalidTypeCast = 142
InvalidUnset = 143
InvalidYieldKeyType = 144
InvalidYieldValueType = 145
LessSpecificArgument = 146
LessSpecificNestedArgumentType = 147
LessSpecificNestedReturnStatement = 148
LessSpecificReturnStatement = 149
ListDestructureNegativeKey = 150
ListDestructureStringKey = 151
ListUsedInReadContext = 152
MatchArmAlwaysTrue = 153
MatchDefaultArmAlwaysExecuted = 154
MatchExpressionOnlyDefaultArm = 155
MatchNotExhaustive = 156
MatchSubjectTypeIsNever = 157
MethodAccessOnNull = 158
MismatchedArrayIndex = 159
MissingApiOrInternal = 160
MissingConstantType = 161
MissingConstructor = 162
MissingMagicMethod = 163
MissingOverrideAttribute = 164
MissingParameterType = 165
MissingPropertyType = 166
MissingRequiredInterface = 167
MissingRequiredParent = 168
MissingReturnStatement = 169
MissingReturnType = 170
MissingTemplateParameter = 171
MixedArgument = 172
MixedArrayAccess = 173
MixedArrayAssignment = 174
MixedArrayIndex = 175
MixedAssignment = 176
MixedClone = 177
MixedDestructuringShape = 178
MixedMethodAccess = 179
MixedOperand = 180
MixedPropertyAccess = 181
MixedPropertyTypeCoercion = 182
MixedReturnStatement = 183
NameAlreadyInUse = 184
NamedArgumentAfterPositional = 185
NamedArgumentNotAllowed = 186
NamedArgumentOverridesPositional = 187
NeverMatchingSwitchCase = 188
NeverReturn = 189
NoValidCatchTypeFound = 190
NoValue = 191
NonClassUsedAsAttribute = 192
NonDocumentedConstant = 193
NonDocumentedMethod = 194
NonDocumentedProperty = 195
NonExistentAttributeClass = 196
NonExistentCatchType = 197
NonExistentClass = 198
NonExistentClassConstant = 199
NonExistentClassLike = 200
NonExistentConstant = 201
NonExistentFunction = 202
NonExistentMethod = 203
NonExistentProperty = 204
NonExistentUseImport = 205
NonIterableObjectIteration = 206
NonStaticAbstractImplementation = 207
NullArgument = 208
NullArrayAccess = 209
NullArrayIndex = 210
NullIterator = 211
NullOperand = 212
NullPropertyAccess = 213
NullableReturnStatement = 214
OverlyWideReturnType = 215
OverrideFinalConstant = 216
OverrideFinalMethod = 217
OverrideFinalProperty = 218
OverrideFinalPropertyHook = 219
ParadoxicalCondition = 220
ParentOutsideClassScope = 221
PossibleMethodAccessOnNull = 222
PossiblyArrayAppendOverflow = 223
PossiblyFalseArgument = 224
PossiblyFalseArrayAccess = 225
PossiblyFalseIterator = 226
PossiblyFalseOperand = 227
PossiblyInvalidArgument = 228
PossiblyInvalidArrayAccess = 229
PossiblyInvalidClone = 230
PossiblyInvalidIterator = 231
PossiblyInvalidOperand = 232
PossiblyNonExistentMethod = 233
PossiblyNonExistentProperty = 234
PossiblyNullArgument = 235
PossiblyNullArrayAccess = 236
PossiblyNullArrayIndex = 237
PossiblyNullIterator = 238
PossiblyNullOperand = 239
PossiblyNullPropertyAccess = 240
PossiblyStaticAccessOnInterface = 241
PossiblyUndefinedArrayIndex = 242
PossiblyUndefinedIntArrayIndex = 243
PossiblyUndefinedStringArrayIndex = 244
PossiblyUndefinedVariable = 245
PropertyTypeCoercion = 246
PsalmTrace = 247
RedundantCast = 248
RedundantComparison = 249
RedundantCondition = 250
RedundantDocblockType = 251
RedundantIssetCheck = 252
RedundantKeyCheck = 253
RedundantLogicalOperation = 254
RedundantNonnullEntryCheck = 255
RedundantNonnullTypeComparison = 256
RedundantNullCoalesce = 257
RedundantNullsafeOperator = 258
RedundantTypeComparison = 259
ReferenceConstraintViolation = 260
ReferenceReusedFromConfusingScope = 261
ReferenceToUndefinedVariable = 262
SelfOutsideClassScope = 263
SideEffectsInCondition = 264
SkipInKeyedDestructuring = 265
SpreadInDestructuring = 266
StaticAccessOnInterface = 267
StaticOutsideClassScope = 268
StringConstantSelector = 269
StringMemberSelector = 270
TemplateConstraintViolation = 271
TooFewArguments = 272
TooManyArguments = 273
TraitConstantOverride = 274
TraitInstantiation = 275
TypeConfirmation = 276
TypeInspection = 277
UndefinedIntArrayIndex = 285
UndefinedStringArrayIndex = 286
UndefinedVariable = 287
UndefinedVariableInClosureUse = 288
UnevaluatedCode = 289
UnhandledThrownType = 290
UnimplementedAbstractMethod = 291
UnimplementedAbstractPropertyHook = 292
UninitializedProperty = 293
UnknownClassInstantiation = 294
UnknownConstantSelectorType = 295
UnknownIteratorType = 296
UnknownMatchSubjectType = 297
UnknownMemberSelectorType = 298
UnknownYieldFromIteratorType = 299
UnreachableElseClause = 300
UnreachableMatchArm = 301
UnreachableMatchDefaultArm = 302
UnreachableSwitchCase = 303
UnreachableSwitchDefault = 304
UnresolvableClassConstant = 305
UnsafeInstantiation = 306
UnusedFunctionCall = 307
UnusedMethod = 308
UnusedMethodCall = 309
UnusedParameter = 310
UnusedProperty = 311
UnusedStatement = 312
UnusedTemplateParameter = 313
UselessControlFlow = 314
WhereConstraintViolation = 315
WriteOnlyProperty = 316
YieldFromInvalidKeyType = 317
YieldFromInvalidSendType = 318
YieldFromInvalidValueType = 319
YieldFromNonIterable = 320
YieldOutsideFunction = 321
Implementations