pub trait FunctionThrowTypeProvider: Provider {
// Required methods
fn targets() -> FunctionTarget
where Self: Sized;
fn get_thrown_exceptions(
&self,
context: &ProviderContext<'_, '_, '_>,
invocation: &InvocationInfo<'_, '_, '_>,
) -> HashSet<Word>;
}Expand description
Provider for getting thrown exception class names from function calls.
Required Methods
Sourcefn targets() -> FunctionTargetwhere
Self: Sized,
fn targets() -> FunctionTargetwhere
Self: Sized,
The functions this provider handles.
Sourcefn get_thrown_exceptions(
&self,
context: &ProviderContext<'_, '_, '_>,
invocation: &InvocationInfo<'_, '_, '_>,
) -> HashSet<Word>
fn get_thrown_exceptions( &self, context: &ProviderContext<'_, '_, '_>, invocation: &InvocationInfo<'_, '_, '_>, ) -> HashSet<Word>
Get the exception class names that a function invocation can throw.
Returns a set of fully qualified exception class names. Returns an empty set if the function doesn’t throw.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".